# wcf dev example

This example sets up a basic 3D configurator by using the Web Configuration Framework (W-CF).
It shows how to use the framework for different use-cases (as a catalog, fetching article information, configurating an article, ...).

The code **should not** be used for productive environments. Its purpose is to show how to use the framework with simple examples. A too deep tech-stack was avoided here (we use only simple JavaScript for DOM manipulation, no React/Vue/Angular or else).

## setup dev environment

- install [node.js](https://nodejs.org/) (use LTS version)
- open terminal in project folder and install dependencies by

```sh
npm ci
```

- to start a local dev server call

```sh
npm start
```

- or to create output files in the `build` folder, call

```sh
npm run build
```

## project structure

The entry point for the project is `public/index.html`. Here are all scripts and styles referenced. The entry point for the scripts is `src/index.ts`.

The naming of the components reflects the naming of the UI components when running the example. So it is easy to find, in which component of the source code to look, for various information (i.e. seeing the short-text of an article in the basket view, just look in the source code of component/basket/ for finding out how to fetch the short-text).

```
wcf-dev-example
├── build (auto-generated by calling 'npm run build')
├── public (all in here will be copied to build folder)
│   └── index.html
├── src
│   ├── index.ts
│   ├── index.css
│   └── components
│       └── *.*
├── package.json (project dependencies)
├── tsconfig.json (compiler options for TypeScript)
└── webpack.config.js (build process config)
```

## rough workflow of the app

- create a session on the server (EAIWS) and init the core application
- insert article from catalog (by user or code)
- fetch and show article information (texts, prices, properties, etc.)
- setup properties of the article in a property-editor, so the user can configure the article
- give options for exporting the current configuration

## notes

For debugging purposes is the app accessible through the browser console, if you type `app`.

To skip entering the gatekeeper id at startup over and over again, the id can be given by an url parameter (i.e. <http://localhost:3000/?gatekeeper_id=5a969885660e5>).
